"""Provide CLI utility for interfacing with data loading operations."""

import logging
from pathlib import Path
from timeit import default_timer as timer

import click

from vrsix import load as load_vcf

_logger = logging.getLogger(__name__)


def _configure_logging() -> None:
    """Configure Python-side logging."""
    logging.basicConfig(
        filename=f"{__package__}.log",
        format="[%(asctime)s] - %(name)s - %(levelname)s : %(message)s",
    )
    logging.getLogger(__package__).setLevel(logging.INFO)


@click.group()
def cli() -> None:
    """Index VRS-annotated VCFs"""
    _configure_logging()


@cli.command()
@click.argument(
    "vcf",
    type=click.Path(
        exists=True, file_okay=True, dir_okay=False, readable=True, path_type=Path
    ),
    nargs=1,
)
@click.argument(
    "uri",
    default=None,
    required=False,
)
@click.option(
    "--db-location",
    type=click.Path(
        file_okay=True, dir_okay=True, readable=True, writable=True, path_type=Path
    ),
)
def load(vcf: Path, uri: str, db_location: Path | None) -> None:
    """Index the VRS annotations in a VCF by loading it into the sqlite DB.

    Optionally provide a custom file URI to describe how to retrieve VCF records after
    index lookup:

        % vrsix load input.vcf gs://my_storage/input.vcf

    \f
    :param vcf_path: path to VCF to ingest
    """
    if db_location and db_location.is_dir():
        db_location = db_location / "vrs_vcf_index.db"
    start = timer()
    load_vcf.load_vcf(vcf, db_location, uri)
    end = timer()
    _logger.info("Processed `%s` in %s seconds", vcf, end - start)



"""Define important attributes for sqlite connection."""

import os
from pathlib import Path

DEFAULT_SQLITE_LOCATION = Path(
    os.environ.get("VRS_VCF_INDEX", Path.home() / ".local" / "share" / "vrsix.db")
)



"""Load VCFs into sqlite index."""

import logging
from pathlib import Path

from vrsix._core import (
    FiletypeError,
    SqliteFileError,
    VcfError,
    VrsixDbError,
    VrsixError,
    vcf_to_sqlite,
)
from vrsix.sqlite import DEFAULT_SQLITE_LOCATION

__all__ = [
    "FiletypeError",
    "SqliteFileError",
    "VcfError",
    "VrsixDbError",
    "VrsixError",
    "load_vcf",
    "vcf_to_sqlite",
]

_logger = logging.getLogger(__name__)


def load_vcf(
    vcf_path: Path, db_location: Path | None = None, vcf_uri: str | None = None
) -> None:
    """Load VRS-annotated VCF into sqlite database.

    :param vcf_path: path to VCF (must exist) to ingest
    :param db_location: path to sqlite DB
    :param vcf_uri: optional URI for original input. Not validated or parsed in any way.
        Used by fetching lib to re-acquire data.
    """
    sqlite_uri = (
        f"sqlite://{DEFAULT_SQLITE_LOCATION}"
        if db_location is None
        else f"sqlite://{db_location}"
    )
    _logger.debug("Using sqlite file located at %s", sqlite_uri)
    vcf_to_sqlite(vcf_path, sqlite_uri, vcf_uri)
